<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Message catalog in Spanish
 *
 * PHP versions 4 and 5
 *
 * LICENSE: Permission to use, copy, modify, and distribute this software and
 * its documentation for any purpose and without fee is hereby
 * granted, provided that the above copyright notice appear in all
 * copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of the
 * author not be used in advertising or publicity pertaining to
 * distribution of the software without specific, written prior
 * permission. The author makes no representations about the
 * suitability of this software for any purpose.  It is provided "as
 * is" without express or implied warranty.
 *
 * @author     Rodrigo Ramírez Norambuena <decipher.hk@gmail.com>
 * @copyright  2003-2012		PgPool Global Development Group
 * @version    CVS: $Id$
 */

$message = array(
    'lang' => 'es',
    'strLang' => 'Español',
    'strVersion' => 'Versión pgpool-II',
    'strNext' => 'Siguiente',
    'strCheck' => 'Chequeo',
    'strDirectoryCheck' => 'Revisión directorio',
    'strParameterCheck' => 'Parámetros de configuración',
    'strFinish' => 'Finalizado',
    'strPgConfFile' => 'Archivo pgpool.conf',
    'strPasswordFile' => 'Archivo pcp.conf',
    'strPgmgtFile' => 'Archivo de configuración de pgpoolAdmin',
    'strTempDir' => 'Directorio de plantillas',
    'strPgpoolCommand' => 'Comando pgpool',
    'strPgpoolCommandOption' => 'Opción del comando pgpool',
    'strCmdC' => 'Limpiar cache de query',
    'strCmdD' => 'Modo depuración',
    'strCmdM' => 'Modo detenido',
    'strCmdLargeD' => 'Descargar archivo pgpool_status',
    'strCmdN' => 'No ejecutar en modo demonio',
    'strCmdLargeC' => 'Descargar el mapeo de oid en la memoria cache de query',
    'strCmdPgpoolFile' => 'pgpool.conf',
    'strCmdPcpFile' => 'pcp.conf',
    'strCmdDesc' => 'En blanco, esta opción es ignorada.',
    'strPgpoolLogFile' => 'Archivo de logs para pgpool',
    'strPcpDir' => 'Directorio PCP ',
    'strPcpTimeout' => 'PCP Timeout',
    'strPcpHostName' => 'Nombre del host PCP',
    'strPcpRefreshTime' => 'Tiempo de actualización',
    'msgCongratulations' => '¡Felicitaciones, herramienta de administración está instalada!',
    'msgDeleteInstallDir' => ' : Elimina este directorio',
    'msgToTop' => 'Arriba'
);

?>
