body {
  margin: 0px;
  font: x-small Verdana, Arial, Helvetica, sans-serif;
}

/* --------------------------------------------------------------------- */
/* header                                                                */
/* --------------------------------------------------------------------- */

h1 {
  margin: 0px;
}
h2 {
  margin-top: 50px;
  padding: 5px;
  background: #8CD8E2;
}
h3 {
  margin-top: 30px;
  padding: 5px;
  background: #F4F8F1;
  border: 2px solid #8CD8E2;
  border-left: 10px solid #8CD8E2;
}

/* --------------------------------------------------------------------- */
/* table                                                                 */
/* --------------------------------------------------------------------- */

table {
  border-top: 1px solid lightsteelblue;
  border-collapse: collapse;
}
th, td {
  padding: 4px 8px;
  border-bottom: 1px solid lightsteelblue;
}
thead th, thead td,
tfoot th, tfoot td,
tr.tr_add_button th,
tr.tr_add_button td {
  background: ghostwhite;
}
tbody th {
  font-weight: normal;
  text-align: left;
}
tbody th.category {
  font-weight: bold;
  color: #709CD1;
  font-size: small;
}
tbody th.category_2 span {
  font-weight: bold;
  color: #7CC9E2;
  font-size: small;
}

table#complete_msg
{
    margin-bottom: 20px;
}

td.pgconfig_msg img {
  vertical-align: middle;
  margin-right: 5px;
  height: 12px;
}

/* --------------------------------------------------------------------- */
/* link                                                                  */
/* --------------------------------------------------------------------- */

a:link {
  color: red;
  text-decoration: none;
}
a:visited {
  color: maroon;
  text-decoration: none;
}
a:link:hover, a:visited:hover {
  color: orangered;
  text-decoration: underline;
}
a img {
  border: none;
}

#div_log a:link, #div_log a:visited {
  color: orangered;
  text-decoration: underline;
}

/* --------------------------------------------------------------------- */
/* input                                                                 */
/* --------------------------------------------------------------------- */

input {
  font: x-small Verdana, Arial, Helvetica, sans-serif;
}
input[type=button], input[type=submit] {
  background: #cfcfcf;

  padding: 5px 7px;
  vertical-align: middle;

  border-width: 0px;
  -webkit-border-radius: 3px;
  -moz-border-radius:    3px;
  border-radius:         3px;
}
input[type=button]:hover, input[type=submit]:hover, input[type=reset]:hover {
  background: #dddddd;
  color: #5f5f5f;
}
input[type=button]:active, input[type=submit]:active, input[type=reset]:active {
  background: #bbbbbb;
  color: #000000;
}
input[type=button].command_active {
  background: yellow;
  border-color: #BC4B00;
}

input[type=button][disabled], input[type=button][disabled]:hover {
  background: #cfcfcf;
  color: #777777;
  text-shadow: #eeeeee 0 1px 0;
}

/* --------------------------------------------------------------------- */
/* radio                                                                 */
/* --------------------------------------------------------------------- */

div.radio_bool {
    margin-bottom: 20px;
    padding: 0px;
}
div.radio_bool input{
    display: none;
}
div.radio_bool label{
    background: #bdc3c7;
    border-right: 1px solid #abb2b7;
    color: #555e64;
    cursor: pointer;
    display: block;
    float: left;
    line-height: 1;
    margin: 0;
    padding: 5px 12px;
    text-align: center;
    transition: .2s;
}
div.radio_bool label:first-of-type{
    border-radius: 3px 0 0 3px;
}
div.radio_bool label:last-of-type{
    border-right: 0px;
    border-radius: 0 3px 3px 0;
}
div.radio_bool input[type="radio"]:checked + label {
    background-color: #a1b91d;
    color: #fff;
    font-weight: bold;
}
div.radio_bool input[type="radio"]:disabled:checked + label {
    background-color: #e1e1e1;
    color: #999999;
}
div.radio_bool input[type="radio"]:disabled + label {
    background-color: #cfcfcf;
    color: #aaaaaa;
}

/* --------------------------------------------------------------------- */
/* text                                                                  */
/* --------------------------------------------------------------------- */

label {
  font-weight: bold;
}
pre {
    background-color: #EFEFFC;
    padding: 5px 15px;
}
p {
    margin: 5px;
}
ul {
  list-style: square;
}
/* --------------------------------------------------------------------- */
/* div                                                                   */
/* --------------------------------------------------------------------- */

/* header */
#header {
  padding: 8px;
  border-bottom: 8px solid white;
  background: steelblue url("images/sea.jpg") no-repeat bottom right;
}

/* menu */
#menu {
  border-top: 1px solid lightsteelblue;
  border-right: 1px solid lightsteelblue;
  float: left;
  width: 176px;
  overflow: hidden;
  background: ghostwhite;
}
#menu ul {
  margin: 0px;
  padding: 0px;
  list-style: none;
}
#menu li {
  border-bottom: 1px solid lightsteelblue;
}
#menu a:link, #menu a:visited {
  padding: 8px 0px;
  display: block;
  color: black;
  background: url("images/marker.gif") no-repeat 8px;
  text-indent: 16px;
  text-decoration: none;
}
#menu a:hover {
  background: antiquewhite url("images/marker.gif") no-repeat 8px;
}

/* content */
#content {
  padding: 8px 8px 40px 185px;
  border-top: 1px solid lightsteelblue;
  background: white url("images/background.gif") repeat-y left;
}

/* submenu in pgconfig */
#submenu {
  padding: 0px 30px 30px 10px;
  background: ghostwhite;
  font-size: x-small;
  border-bottom: 1px solid lightsteelblue;
}
#submenu h3 {
  border: 0px;
}
#submenu ul li {
  border: 0px;
}
#submenu ul li a:link {
  padding: 3px;
}

/* footer */
#footer {
  padding: 8px 8px 20px;
  clear: left;
  color: white;
  background: lightsteelblue;
}
#footer address {
  font-style: normal;
}
#footer p {
  margin: 0px;
  float: right;
}
#footer a:link, #footer a:visited {
  color: white;
  font-weight: bold;
}

/* help */
#help {
  float: right;
}

/* commands */
#div_commands {
  margin-bottom: 20px;
}

/* --------------------------------------------------------------------- */
/* other                                                                 */
/* --------------------------------------------------------------------- */

.hidden {
  display: none;
}
.odd {
}
.even {
  background: azure;
}
.error {
  font-weight: normal;
  text-align: left;
  background: #FFB499;
}
.right_border {
  border-right: 1px solid lightsteelblue;
  border-collapse: collapse;
}
.message {
    margin-top: 10px;
    border: 5px solid lightsteelblue;
    border-radius: 5px;
    background-color: ghostwhite;
    padding: 10px;
}
.message h3 {
    border: 0px solid black;
    color: #4682B4;
}
.message p {
    font-family: monospace;
    border-bottom: 1px dotted #cccccc;
}
.param_group {
    background-color: #78A1D3;
    padding: 3px 5px;
    border-radius: 3px;
    color: white;
}
p.check_error {
    color: red;
    font-weight: bold;
}
p.check_error span.error {
    background: red;
    color: white;
    font-weight: bold;
    padding: 1px 5px;

    -webkit-border-radius: 3px;
    -moz-border-radius:    3px;
    border-radius:         3px;
}
td.command_option {
    padding-left: 30px;
}

/* --------------------------------------------------------------------- */
/* Refresh info                                                          */
/* --------------------------------------------------------------------- */

div.auto_reloading {
  float: right;
  margin-bottom: 10px;
}
div.auto_reloading img {
  vertical-align: middle;
  height: 13px;
}
div.auto_reloading span {
  padding: 2px 5px;
  margin: 5px;
  color: #2D1D00;
}


form.pgconfig table {
    width: 800px;
}
form.pgconfig table tr:hover {
    background: #f6f6f6;
}
form.pgconfig th.colname {
    width: 500px;
}
form.pgconfig tr.group th {
    padding-left: 30px;
}
