  <address>
  Version {$version|escape}<br />
  Copyright &copy; 2006 - {date('Y')} <a href="http://pgpool.projects.postgresql.org/">pgpool Global Development Group</a>. All rights reserved.
  </address>
