<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Message catalog in English
 *
 * PHP versions 4 and 5
 *
 * LICENSE: Permission to use, copy, modify, and distribute this software and
 * its documentation for any purpose and without fee is hereby
 * granted, provided that the above copyright notice appear in all
 * copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of the
 * author not be used in advertising or publicity pertaining to
 * distribution of the software without specific, written prior
 * permission. The author makes no representations about the
 * suitability of this software for any purpose.  It is provided "as
 * is" without express or implied warranty.
 *
 * @author     Ryuma Ando <ando@ecomas.co.jp>
 * @copyright  2003-2008		PgPool Global Development Group
 * @version    CVS: $Id$
 */

$message = array(
    'lang' => 'zh_cn',
    'strLang' => '简体中文',
    'strNext' => '下一步',
    'strCheck' => '检测',
    'strDirectoryCheck' => '路径检测',
    'strParameterCheck' => '参数设置',
    'strFinish' => '完成',
    'strPgConfFile' => 'pgpool.conf 文件',
    'strPasswordFile' => 'pcp.conf 文件',
    'strPgmgtFile' => 'pgpoolAdmin 设置文件',
    'strTempDir' => '临时目录',
    'strPgpoolCommand' => 'pgpool 命令',
    'strPgpoolCommandOption' => 'pgpool 命令选项',
    'strCmdC' => '清空查询缓存',
    'strCmdD' => '调试模式',
    'strCmdM' => '停止模式',
    'strCmdLargeD' => '忽略 pgpool_status 文件',
    'strCmdN' => '不以守护进程模式运行',
    'strCmdPgpoolFile' => 'pgpool.conf',
    'strCmdPcpFile' => 'pcp.conf',
    'strCmdDesc' => '如果为空，本选项被忽略',
    'strPgpoolLogFile' => 'pgpool 日志文件',
    'strPcpDir' => 'PCP 目录',
    'strPcpTimeout' => 'PCP 超时',
    'strPcpHostName' => 'PCP 主机名',
    'strPcpRefreshTime' => '刷新时间',
    'msgCongratulations' => '恭喜，pgpool 管理工具安装完成。',
    'msgDeleteInstallDir' => ' : 请删除这个目录',
    'msgToTop' => '返回'
);

?>
